<template>
    <div class="row">
        <!-- Panel izquierdo: Lista de productos en el carrito -->
        <div class="col-md-6 col-xs-12">
            <div class="left-panel">
                <div v-for="(item, index) in products" :key="index">
                    <full-cart-item :product="item" />
                </div>
                <div class="link-more">
                    <a href="/tienda">Agregar más productos</a>
                </div>
            </div>
            <FreeShippingAlert />
        </div>

        <!-- Panel derecho: Proceso de resumen y factuaracion -->
        <div class="col-md-6 col-xs-12">
            <div class="full-cart-module">
                <a v-if="currentStep !== 'cartSummary'" class="back-buttom" @click="goBack">
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
                        <path
                            fill="currentColor"
                            d="M21 11H6.414l5.293-5.293l-1.414-1.414L2.586 12l7.707 7.707l1.414-1.414L6.414 13H21z"
                        />
                    </svg>
                </a>

                <CartSummary
                    v-if="currentStep === 'cartSummary'"
                    :payment-methods="paymentMethods"
                    @confirm="goToBillingDetail"
                />
                <BillingDetail
                    v-if="currentStep === 'billingDetail'"
                    :payment-methods="paymentMethods"
                    @submit="goToCheckoutSummary"
                />
            </div>
        </div>
    </div>
</template>

<script setup>
import { computed, onMounted, ref } from "vue";
import FullCartItem from "./FullCartItem.vue";
import CartSummary from "./Summary/CartSummary.vue";
import BillingDetail from "./Billing/BillingDetail.vue";
import FreeShippingAlert from "./FreeShippingAlert.vue";
import { cartStore } from "../../js/stores/cart.js";
import { useParametersStore } from "../../js/stores/parameters";

// Props
const props = defineProps({
    freeShippingMessage: {
        type: String,
        required: true,
    },
    discountRate: {
        type: String, // o Number si preferís
        required: true,
    },
    paymentMethods: {
        type: Array,
        required: true,
    },
});

const store = cartStore();
const parameters = useParametersStore();

const products = computed(() => store.items);

const currentStep = ref("cartSummary");

const goToBillingDetail = () => {
    currentStep.value = "billingDetail";

    if (process.env.MARKETING_TOOLS_ENABLED) {
        // try {
        trackEventBeginCheckout();
        // } catch (e) {}
    }
};

const goToCheckoutSummary = () => {
    currentStep.value = "checkoutSummary";
};

function trackEventBeginCheckout() {
    let contentIdMeta = [];
    let contentsMeta = [];

    store.items.forEach((item) => {
        contentIdMeta.push(item.variantSku ? item.variantSku : item.sku);
        contentsMeta.push({
            id: item.variantSku ? item.variantSku : item.sku,
            quantity: item.quantity,
            item_price: item.price,
        });
    });

    let customData = {
        content_ids: contentIdMeta,
        contents: contentsMeta,
        currency: "ARS",
        value: store.getTotalCart(), // Valor total del carrito
        num_items: store.items.length,
    };

    // Generar ID de evento aleatorio
    const eventId = "ev_" + Math.random().toString(36).substring(2, 15) + Math.random().toString(36).substring(2, 15);

    // Evento para el Pixel de Meta (browser-side)
    if (typeof fbq !== "undefined") {
        fbq("track", "InitiateCheckout", customData, { eventID: eventId });
    }

    // Datos para la Conversions API (server-side)
    const serverData = {
        eventName: "InitiateCheckout",
        eventId: eventId,
        customData: {
            ...customData,
        },
        actionSource: "website",
    };

    // Enviar datos al servidor para la Conversions API
    fetch("/integration/meta/event", {
        method: "POST",
        headers: {
            "Content-Type": "application/json",
        },
        body: JSON.stringify(serverData),
    })
        .then((response) => response.json())
        .catch((error) => {
            console.error("Error on Conversions API:", error);
        });

    let cartItemsGtm = [];
    store.items.forEach((item) => {
        cartItemsGtm.push({
            item_id: item.variantSku ? item.variantSku : item.sku,
            item_name: item.name,
            quantity: item.quantity,
            price: item.price,
        });
    });

    dataLayer.push({ ecommerce: null }); // Clear the previous ecommerce object.
    dataLayer.push({
        event: "begin_checkout",
        ecommerce: {
            currency: "ARS",
            value: store.getTotalCart(),
            items: cartItemsGtm,
        },
    });
}

const goBack = () => {
    if (currentStep.value === "checkoutSummary") {
        currentStep.value = "billingDetail";
    } else if (currentStep.value === "billingDetail") {
        currentStep.value = "cartSummary";
    }
};

onMounted(() => {
    parameters.setFreeShippingMessage(props.freeShippingMessage.trim());
    parameters.setDiscountRate(Number(props.discountRate));
});
</script>

<style scoped>
.row {
    display: flex;
}

.full-cart-module {
    padding: 0 10px 10px;
    background-color: transparent;
}

.left-panel {
    background-color: white;
    padding: 10px 29px;
    margin-bottom: 31px;
    border-radius: 8px;
}

.link-more {
    padding: 14px 0;
    font-size: 15px;
    font-weight: 700;
}

.back-buttom {
    cursor: pointer;
}

@media screen and (width <= 600px) {
    .left-panel {
        padding: 10px 20px;
    }
}
</style>
